# -*- encoding:utf-8 -*-
import concurrent.futures
import json
from flask_app.general.doubao import doubao_model
from flask_app.general.json_utils import clean_json_string
from flask_app.general.通义千问long import qianwen_long, qianwen_long_stream


def generate_continue_query(original_query, original_answer):
    """
    生成继续回答的查询内容。

    参数:
    - original_query (str): 原始问题。
    - original_answer (str): 上一次模型的回答（可能是不完整的 JSON 字符串）。

    返回:
    - continue_query (str): 用于继续回答的查询内容。
    """
    continue_query = f"""以下是问题及已有的回答（被截断），请在该回答后继续回答，无需重复已有的回答：

问题: {original_query}

已有的被截断的回答：
{original_answer}

请接着已有回答继续输出后续内容。你的回答无需是完整的 JSON 格式，我会将你的回答与已有内容拼接为完整的 JSON。请专注于生成后续内容即可。"""
    return continue_query


def continue_answer(original_query, original_answer, model_type=1, file_id=None):
    """
    实现“继续回答”功能，支持选择不同模型。

    参数:
    - original_query (str): 原始问题。
    - original_answer (str): 上一次模型的回答（可能是不完整的 JSON 字符串）。
    - model_type (int): 指定使用的模型类型（1: doubao_model, 2: qianwen_long, 3: qianwen_long_stream）。
    - file_id (str): 可选的文件 ID，默认为 None。

    返回:
    - json_data (dict): 拼接后的完整 JSON 数据。如果解析失败，返回 None。
    """
    # 生成继续查询的 Prompt
    continue_query = generate_continue_query(original_query, original_answer)
    # print("继续问答")
    # print(continue_query)

    # 根据模型类型选择调用的模型
    if model_type == 1:  # 使用 doubao_model
        model_res = doubao_model(continue_query)
    elif model_type == 2:  # 使用 qianwen_long
        if file_id is None:
            raise ValueError("file_id 必须在使用 qianwen_long 模型时提供！")
        model_res = qianwen_long(file_id, continue_query)
    elif model_type == 3:  # 使用 qianwen_long_stream
        if file_id is None:
            raise ValueError("file_id 必须在使用 qianwen_long_stream 模型时提供！")
        model_res = qianwen_long_stream(file_id, continue_query)
    else:
        raise ValueError(f"无效的模型类型: {model_type}")

    # 拼接原始回答和模型的继续回答
    # 删除 original_answer 的最右边的 `"` 和 `\n`
    clean_original = original_answer.rstrip('"\n')

    # 删除 model_res 的最左边的 `"` 和 `\n`
    clean_model = model_res.lstrip('"\n')

    # 拼接字符串
    full_answer = clean_original + clean_model
    # print("原来的回答：")
    # print(clean_original)
    # print("---------------------")
    # print("第二次回答")
    # print(clean_model)
    # print("---------------------")
    # # 打印拼接后的字符串
    # print("拼接后的完整回答字符串：")
    # print(full_answer)

    # 尝试解析为 JSON
    try:
        json_data = clean_json_string(full_answer)
        return json_data
    except json.JSONDecodeError as e:
        print("JSON 拼接失败，错误信息如下：")
        print(e)
        return None

def process_continue_answers(questions_to_continue, model_type, file_id):
    """
    并行处理需要调用 `continue_answer` 的问题。

    参数:
    - questions_to_continue (list of tuples): 需要继续回答的问题，每个元素是 (original_query, parsed_answer)。
    - model_type (int): 指定使用的模型类型。
    - file_id (str): 可选的文件 ID，默认为 None。
    - model_type
    返回:
    - dict: 继续回答后的结果合并。
    """
    continued_results = {}
    if not questions_to_continue:
        return continued_results

    with concurrent.futures.ThreadPoolExecutor(max_workers=min(10, len(questions_to_continue))) as executor:
        future_to_question = {
            executor.submit(
                continue_answer,
                original_query,
                parsed_answer,
                model_type,
                None if model_type == 1 else file_id
            ): original_query
            for original_query, parsed_answer in questions_to_continue
        }

        for future in concurrent.futures.as_completed(future_to_question):
            original_query = future_to_question[future]
            try:
                continued_result = future.result()
                if continued_result:  # 确保结果不为空
                    if isinstance(continued_result, dict):
                        continued_results.update(continued_result)
                    else:
                        print(f"警告: continued_result 不是字典类型，无法更新。")
            except Exception as e:
                print(f"在处理问题 '{original_query}' 时发生错误: {e}")    #TODO:排查一下
                return {}

    return continued_results

# 示例使用
if __name__ == "__main__":
    original_query = """请根据货物标中采购要求部分的内容，告诉我"▲乘客电梯"的技术参数或采购要求是什么。由于该货物存在 4 种不同的采购要求或技术参数，请逐一列出，并以 JSON 格式返回结果。请以'货物名-编号'区分多种型号，编号为从 1 开始的自然数，依次递增，即第一个键名为"▲乘客电梯-1"；键值为一个列表，列表中包含若干描述"▲乘客电梯"的技术参数或采购要求或功能说明的字符串，请按原文内容回答，保留三角▲、五角★和序号（若有），不可擅自增删内容，尤其是不可擅自添加序号。

要求与指南：
1. 你的键值应该全面，不要遗漏。
-a.若技术参数或采购要求在表格中，那么单元格内的内容基本都要涵盖
-对于单元格内以序号分隔的各条参数要求，应逐条提取，并分别作为键值中的字符串列表项。
-对于无序号标明且在同一单元格内的参数要求或功能说明，也要根据语义分别添加进键值中。
-b.若技术参数或采购要求在正文部分，应准确定位到与目标货物（设备、系统、功能模块）相关的内容，将其后的技术参数或采购要求或功能说明完整提取，逐一添加到键值的字符串列表中，不得擅自添加或修改序号。
2. 如果存在嵌套结构，且原文为Markdown 的表格语法，如'摄像机|有效像素|≥900W像素'， 请不要返回该Markdown语法，而是使用冒号':'将相关信息拼接在一起，生成一条完整且清晰的技术参数（或采购要求）描述，作为列表中的一个字符串。如"摄像机：有效像素：≥900W像素"。
3. 字符串中的内容为具体的技术参数要求或采购要求，请不要返回诸如'（1）高清录像功能'这种标题性质且不能体现要求的内容。
4. 如果该货物没有相关采购要求或技术参数要求，键值应为空列表[]。

### 示例输出1如下：
{
"交换机-1": [
"★1、支持固化千兆电口≥8 个，固化千兆光口≥2 个，桌面型设备;",
"2、支持静态链路聚合"
],
"交换机-2": [
"1、交换容量≥52Gbps，包转发率≥38.69Mpps，",
"2、提供国家强制性产品认证证书及测试报告（3C）",
"★能实现信号控制独立传输"
]
}

### 示例输出2如下（包含嵌套结构）：
{
"摄像机-1": [
"摄像机：有效像素：≥900W像素",
"摄像机：最低照度：彩色≤0.001lx",
"协议：routes 接口开放：具备；▲支持标准 ONVIF 协议与第三方厂家设备进行互联；支持 GB/T28181；应提供 SDK"
],
"摄像机-2": [
"支持夜视", "支持云存储"
]
}

文件内容：## 第三章采购需求

## 前注

1.根据《关于规范政府采购进口产品有关工作的通知》及政府采购管理部门的相关规定,下列采购需求中标注进口产品的货物均已履行相关论证手续,经核准采购进口产品,但不限制满足招标文件要求的国内产品参与竞争。未标注进口产品的货物均为拒绝采购进口产品。

2.下列采购需求中:如属于《节能产品政府采购品目清单》中政府强制采购的节能产品,则投标人所投产品须具有市场监管总局公布的《参与实施政府采购节能产品认证机构目录》中的认证机构出具的、处于有效期内的节能产品认证证书。

3.下列采购需求中:标注▲的产品(核心产品),投标人在投标文件《主要中标标的承诺函》中填写名称、品牌、规格、型号、数量、单价等信息。

4.中标人必须确保整体通过采购人及有关主管部门验收,所发生的验收费用由中标人承担;如投标人因未及时现场考察而导致的报价缺项漏项或中标后无法完工,投标人自行承担一切后果。

一、采购需求前附表

<table border="1" ><tr>
<td colspan="1" rowspan="1">序号</td>
<td colspan="1" rowspan="1">条款名称</td>
<td colspan="1" rowspan="1">内容、说明与要求</td>
</tr><tr>
<td colspan="1" rowspan="2">1 </td>
<td colspan="1" rowspan="2">付款方式</td>
<td colspan="1" rowspan="1">合同签订后付合同款的50%作为预付款;货到现场后支付合同款的30%作为到货款;四台电梯全部安装验收合格后(指四台电梯全部安装、调试、检测、</td>
</tr><tr>
<td colspan="1" rowspan="1">验收合格并经国家认可的检验机构出具符合国家电梯产品标准的质量检测报告后)支付合同款的17%;新装电梯两年免费质保期内每年支付合同款的1.5%</td>
</tr><tr>
<td colspan="1" rowspan="1">2 </td>
<td colspan="1" rowspan="1">供货及安装地点</td>
<td colspan="1" rowspan="1">安徽省生态环境厅,采购人指定地点</td>
</tr><tr>
<td colspan="1" rowspan="1">3 </td>
<td colspan="1" rowspan="1">供货及安装期限</td>
<td colspan="1" rowspan="1">1、供货安装期限:合同签订后接采购人书面通知书之日起120个日历日内,分两批次,两两更换,每批次60个日历日内;2、检测合格期限:调试完成后30个日历日内取得检测合格证书</td>
</tr><tr>
<td colspan="1" rowspan="1">4 </td>
<td colspan="1" rowspan="1">免费质保期</td>
<td colspan="1" rowspan="1">自行业主管部门验收合格取证并交付使用后2年</td>
</tr><tr>
<td colspan="1" rowspan="1">5 </td>
<td colspan="1" rowspan="1">符合性审查业绩</td>
<td colspan="1" rowspan="1">自2013年1月1日以来(以合同签订时间为准),所投电梯(与本次所投电梯同品牌同型号)须具有供货安装项目业绩。注:1、投标文件中提供业绩合同扫描件,若合同无法体现签订时间、供货内容、电梯品牌型号等关键评审因素的,须同时提供业主(合同甲方)证明材料扫描件,否则不予认可。2、业绩为产品业绩,不限定合同签订主体。</td>
</tr><tr>
<td colspan="1" rowspan="1">6 </td>
<td colspan="1" rowspan="1">整梯型式试验报告</td>
<td colspan="1" rowspan="1">投标文件中提供所投电梯的整梯型式试验报告扫描件</td>
</tr></table>

## 二、货物需求

根据项目定位,电梯参考品牌:三菱、日立、奥的斯、蒂森克虏伯、通力、迅达。(注:参考品牌仅为参考,不具有限定性)

1.项目实施地点(交货地点):合肥市政务文化新区怀宁路1766号生态环境厅

2.本项目采购的四部电梯,一部电梯为18层18站(-1层至17层),为消防兼无障碍功能电梯,带有消防运行功能;其他3部电梯:1部为18层18站(-1层至17层),为消防兼无障碍功能电梯,带有消防运行功能;1部为18层18站

(-1层至17层),为无障碍功能电梯;1部电梯为17层17站(1层至17层), 为无障碍功能电梯(无障碍功能具备盲文按钮、语音报站、残疾人操纵箱、后壁整壁镜面不锈钢)。现将采购电梯的额定载重量及额定速度要求列表如下,电梯井道尺寸及各层高提供如下,具体尺寸以现场实测为准。中标人应充分复核查验井道尺寸,确保和中标电梯产品相匹配并及时提供予留洞的位置、尺寸和电梯机房、底坑的支反力要求,中标人应及时根据现场(机房、井道、底坑、层站等)勘察结果,提出全部(土建)需要整改的项目内容(包括顶层高度不够需要将现有机房局部抬高的费用以及底坑深度下挖浇筑的费用)报给采购人。

所投标电梯设备应满足以下要求(所提供的井道尺寸仅作为参考,具体以中标人在服务实施前现场勘测的实际尺寸为准,因尺寸不满足要求的则中标人负责整改),投标人在投标文件中须响应以下全部内容,未响应的投标无效。

<table border="1" ><tr>
<td colspan="1" rowspan="1"></td>
<td colspan="1" rowspan="1">▲乘客电梯(3台)</td>
<td colspan="1" rowspan="1">▲乘客电梯(1台)</td>
</tr><tr>
<td colspan="1" rowspan="1">控制方式</td>
<td colspan="1" rowspan="1">三台智能群管理</td>
<td colspan="1" rowspan="1">台集选</td>
</tr><tr>
<td colspan="1" rowspan="1">调速方式</td>
<td colspan="1" rowspan="1">全电脑控制交流变压变频调速</td>
<td colspan="1" rowspan="1">全电脑控制交流变压变频调速</td>
</tr><tr>
<td colspan="1" rowspan="1">额定载重量(kg) </td>
<td colspan="1" rowspan="1">1000 </td>
<td colspan="1" rowspan="1">1000 </td>
</tr><tr>
<td colspan="1" rowspan="1">额定速度(m/s) </td>
<td colspan="1" rowspan="1">2.0 </td>
<td colspan="1" rowspan="1">2.0 </td>
</tr><tr>
<td colspan="1" rowspan="1">停靠站数(站)</td>
<td colspan="1" rowspan="1">2台18层18站18门;1台17层17站17门;</td>
<td colspan="1" rowspan="1">18层18站18门</td>
</tr><tr>
<td colspan="1" rowspan="1">轿厢内尺寸(mm× mm) </td>
<td colspan="1" rowspan="1">1600(宽)×1400(深)×2500(高) </td>
<td colspan="1" rowspan="1"></td>
</tr><tr>
<td colspan="1" rowspan="1">井道尺寸(mmXmm </td>
<td colspan="1" rowspan="1">2150(宽)*2300(深)(一台有300*200角柱) </td>
<td colspan="1" rowspan="1">2150(宽)*2100(深) </td>
</tr></table>

<table border="1" ><tr>
<td colspan="1" rowspan="1">顶层高度(mm) </td>
<td colspan="1" rowspan="1">4600 </td>
<td colspan="1" rowspan="1">4600 </td>
</tr><tr>
<td colspan="1" rowspan="1">底坑深度(mm) </td>
<td colspan="1" rowspan="1">1600 </td>
<td colspan="1" rowspan="1">1600 </td>
</tr><tr>
<td colspan="1" rowspan="1">提升高度(米)</td>
<td colspan="1" rowspan="1">73 </td>
<td colspan="1" rowspan="1">69 </td>
</tr><tr>
<td colspan="1" rowspan="1">曳引机</td>
<td colspan="1" rowspan="1">永磁同步无齿轮</td>
<td colspan="1" rowspan="1">永磁同步无齿轮</td>
</tr><tr>
<td colspan="1" rowspan="1">净开门尺寸(mm× mm) </td>
<td colspan="1" rowspan="1">900(宽)×2100(高) </td>
<td colspan="1" rowspan="1">900(宽)×2100(高) </td>
</tr><tr>
<td colspan="1" rowspan="1">开门方式</td>
<td colspan="1" rowspan="1">中分式</td>
<td colspan="1" rowspan="1">中分式</td>
</tr><tr>
<td colspan="1" rowspan="2">装饰要求</td>
<td colspan="1" rowspan="1">轿厢前壁、两侧壁:304发纹不锈钢,厚度不低于1.0mm 轿厢后壁:镜面不锈钢</td>
<td colspan="1" rowspan="1">轿厢前壁、两侧壁:304发纹不锈钢,厚度不低于1.0mm 轿厢后壁:镜面不锈钢</td>
</tr><tr>
<td colspan="1" rowspan="1">1、轿门和轿厢采用发纹不锈钢。2、首层采用304发纹不锈钢大门套,其它层采用发纹不锈钢小门套。厚度不低于1.0mm,款式:按照更换之前的款式做。</td>
<td colspan="1" rowspan="1">1、轿门和轿厢采用发纹不锈钢。2、首层采用304发纹不锈钢大门套,其它层采用发纹不锈钢小门套。厚度不低于1.0mm,款式:按照更换之前的款式做。</td>
</tr><tr>
<td colspan="1" rowspan="1"></td>
<td colspan="1" rowspan="1">3、轿厢后壁设有不小于15寸的电梯广告机。</td>
<td colspan="1" rowspan="1">3、轿厢后壁设有不小于15寸的电梯广告机。</td>
</tr><tr>
<td colspan="1" rowspan="1">操纵箱及外召唤</td>
<td colspan="1" rowspan="1">面板材料采用发纹不锈钢,LCD液晶显示方向及位置指示器。轿厢增设主副操作箱。</td>
<td colspan="1" rowspan="1">面板材料采用发纹不锈钢,LCD液晶显示方向及位置指示器。轿厢增设主副操作箱。</td>
</tr><tr>
<td colspan="1" rowspan="1">电梯功能</td>
<td colspan="1" rowspan="1">1、无障碍功能电梯(具备盲文按钮、语音报站、残疾人操纵箱、后壁整壁镜面不锈钢)。2、轿厢冷暖空调。3、其中一台具备消防运行功能。</td>
<td colspan="1" rowspan="1">1、无障碍功能电梯(具备盲文按钮、语音报站、残疾人操纵箱、后壁整壁镜面不锈钢)。2、轿厢冷暖空调3、具备消防运行功能。</td>
</tr></table>

### 3. 电梯功能

投标人所投电梯须满足以下功能,投标人在投标文件中须响应以下全部内容未响应的投标无效。

<table border="1" ><tr>
<td colspan="1" rowspan="1">1 </td>
<td colspan="1" rowspan="1">方向显示灯</td>
</tr><tr>
<td colspan="1" rowspan="1">2 </td>
<td colspan="1" rowspan="1">超速保护功能</td>
</tr><tr>
<td colspan="1" rowspan="1">3 </td>
<td colspan="1" rowspan="1">门采用全光幕保护</td>
</tr><tr>
<td colspan="1" rowspan="1">4 </td>
<td colspan="1" rowspan="1">配置后备电源切换系统,以实现“轿厢应急照明”及“轿厢、机房及控制室在停电时实现五方通话”等功能。</td>
</tr><tr>
<td colspan="1" rowspan="1">5 </td>
<td colspan="1" rowspan="1">轿厢应急照明(LED照明)</td>
</tr><tr>
<td colspan="1" rowspan="1">6 </td>
<td colspan="1" rowspan="1">轿厢、机房及控制室五方对讲通话(机房至监控室的布线由采购人负责)</td>
</tr><tr>
<td colspan="1" rowspan="1">7 </td>
<td colspan="1" rowspan="1">司机操作服务</td>
</tr><tr>
<td colspan="1" rowspan="1">8 </td>
<td colspan="1" rowspan="1">控制柜至轿厢预留防干扰视频电缆及接口,根据采购人要求在适当位置配置电梯专用数字式彩色摄像头</td>
</tr><tr>
<td colspan="1" rowspan="1">9 </td>
<td colspan="1" rowspan="1">泊梯功能</td>
</tr><tr>
<td colspan="1" rowspan="1">10 </td>
<td colspan="1" rowspan="1">安全停靠</td>
</tr><tr>
<td colspan="1" rowspan="1">11 </td>
<td colspan="1" rowspan="1">不能开门时就近层停靠</td>
</tr><tr>
<td colspan="1" rowspan="1">12 </td>
<td colspan="1" rowspan="1">门异常检查装置</td>
</tr><tr>
<td colspan="1" rowspan="1">13 </td>
<td colspan="1" rowspan="1">重复关门</td>
</tr><tr>
<td colspan="1" rowspan="1">14 </td>
<td colspan="1" rowspan="1">超载报警</td>
</tr><tr>
<td colspan="1" rowspan="1">15 </td>
<td colspan="1" rowspan="1">重开梯门</td>
</tr><tr>
<td colspan="1" rowspan="1">16 </td>
<td colspan="1" rowspan="1">开关门时间自动调整</td>
</tr><tr>
<td colspan="1" rowspan="1">17 </td>
<td colspan="1" rowspan="1">反向内指令自动消除功能</td>
</tr><tr>
<td colspan="1" rowspan="1">18 </td>
<td colspan="1" rowspan="1">轿厢照明、风扇自动关闭</td>
</tr><tr>
<td colspan="1" rowspan="1">19 </td>
<td colspan="1" rowspan="1">满载不停</td>
</tr><tr>
<td colspan="1" rowspan="1">20 </td>
<td colspan="1" rowspan="1">故障自检测功能</td>
</tr><tr>
<td colspan="1" rowspan="1">21 </td>
<td colspan="1" rowspan="1">火警紧急返回</td>
</tr><tr>
<td colspan="1" rowspan="1">22 </td>
<td colspan="1" rowspan="1">消防电梯配备紧急消防员服务</td>
</tr><tr>
<td colspan="1" rowspan="1">23 </td>
<td colspan="1" rowspan="1">自动恢复</td>
</tr><tr>
<td colspan="1" rowspan="1">24 </td>
<td colspan="1" rowspan="1">(厅、轿厢)呼梯/登记</td>
</tr><tr>
<td colspan="1" rowspan="1">25 </td>
<td colspan="1" rowspan="1">电动机空载保护功能</td>
</tr><tr>
<td colspan="1" rowspan="1">26 </td>
<td colspan="1" rowspan="1">停车在非门区报警</td>
</tr><tr>
<td colspan="1" rowspan="1">27 </td>
<td colspan="1" rowspan="1">位置异常自动校正</td>
</tr><tr>
<td colspan="1" rowspan="1">28 </td>
<td colspan="1" rowspan="1">无呼自返基站功能</td>
</tr><tr>
<td colspan="1" rowspan="1">29 </td>
<td colspan="1" rowspan="1">运行次数显示功能</td>
</tr><tr>
<td colspan="1" rowspan="1">30 </td>
<td colspan="1" rowspan="1">启动补偿功能</td>
</tr><tr>
<td colspan="1" rowspan="1">31 </td>
<td colspan="1" rowspan="1">层高自测定功能</td>
</tr><tr>
<td colspan="1" rowspan="1">32 </td>
<td colspan="1" rowspan="1">无效内指令自动清除功能</td>
</tr><tr>
<td colspan="1" rowspan="1">33 </td>
<td colspan="1" rowspan="1">轿内误登记信号取消功能</td>
</tr><tr>
<td colspan="1" rowspan="1">34 </td>
<td colspan="1" rowspan="1">并联功能</td>
</tr><tr>
<td colspan="1" rowspan="1">35 </td>
<td colspan="1" rowspan="1">微动平层功能</td>
</tr></table>

## 三、技术要求

投标人在投标文件中须响应以下全部技术要求内容,未响应的投标无效

1. 电梯类型:符合招标文件要求

2. 控制系统:网络化架构、32位多微机控制系统。要求三台智能联控,一台18层消防梯独立运行。

3.拖动方式:交流变频变压调速系统(VVVF)

4.电源:动力AC380V/50HZ 三相五线制;照明AC220V/50HZ 单相三线。

5. 召唤按钮面板:面板材料采用发纹不锈钢,单色液晶显示方向及位置指示器每台电梯使用层每层一套。

6.轿厢壁:304发纹不锈钢,不锈钢板厚均为δ≥1.0mm。

7.轿厢高度及装饰:轿厢装饰后净高度不小于2.5米,采用豪华型天花,LED 照明,项目实施前根据不同梯型的使用性质提供三种不同规格商务电梯轿厢装饰方案供采购人选择(费用包含在本次投标报价中)。

8.各个厅门和门套均要求按原实际尺寸订做,层层采用304发纹不锈钢,大门套所用304不锈钢板厚度δ≥1.0mm,款式:按照更换之前的款式设计。

9.厢底材质:中标人提供大理石地板

10.层、轿门地坎:高强度铝合金

11.轿厢操纵箱:发纹不锈钢(整个操纵箱)

12.服务实施前向采购人出具所投电梯的规格参数表和配置功能表原件。

13. 服务实施前向采购人出具所投电梯主要材料、零部件、配套件的供货清单(包括名称、位置、单价、用途、规格型号、制造商、产地等)。

14. 服务实施前向采购人提供所用群控程序功能的详细列表,如果上述所要求的电梯功能有与所用群控程序相矛盾的,需加以说明。

15. 服务实施前向采购人提供电梯保用期后五年内所需的备品备件清单及价格

16. 质保期满后,保证设备维修保养所需的备品配件

17.设备到场后,在采购人提供堆放场地上负责保管

18.随机提供的备品备件、专用工具等,供货安装时提供详细清单

19.项目实施前明确质保期满后的正常年维保费用(清包)供采购人参考

20.轿厢地板:地板相对轿厢地坎下凹20mm,采购人提供石材,中标人按照采购人要求的图案安装石材地板;

21.1000KG客梯预留装饰重量150公斤

22.轿厢内应配置语音报站系统

23.通风设施:轴流风扇。

## 四、质量、服务要求

1.中标人提供的电梯设备的制造、安装与验收须符合国标《电梯制造与安装安

全规范》(GB7588—2003)、《电梯技术条件》(GB/T10058-2009)、《电梯安装验收规范》(GB10060—2011)中的规定。电梯安装完毕后,必须确保该设备一次性通过特种设备检验部门的监督检验。

2. 项目周期(包括制造商生产时间、供货、安装及验收在内)不超过合同签订之日起六个月,两两更换,包括旧梯拆除时间。

3.中标人要加强本现场电梯安装质量管理,电梯安装维修人员需具备《特种设备作业人员证》,安装经验丰富。要求电梯验收投入使用后运行平稳、乘坐舒适、平层准确,轿厢、机房噪声满足要求,并且长时间候梯率低。

4.本次电梯更换安装工作按照《电梯制造与安装安全规范》(GB7588—2003)、《电梯安装验收规范》(GB10060-2011)和《电梯工程施工质量验收规范》(GB50310-2002) 等电梯相关标准的要求进行。

5.项目实施前中标人须明确所投电梯随机提供的备品备件、专用工具等的详细清单,注明现行价格。

6.中标人项目实施前提供所投产品彩图、技术参数表和相应的机房(包括混凝土开孔图)、井道图纸等技术资料。

7.中标人供货前向采购人提供产品具体的质保期内、外的服务承诺。中标人按《电梯使用管理与维护保养规则》(TSGT5001-2009) 要求,对中标人与设备生产厂家须为中标设备提供质保期2年,自四台电梯全部安装完毕并经质监局监督检验合格之日起算。质保期内进行免费维保。对质保期内出现的所有质量问题,中标人与电梯生产厂家必须及时免费上门包修,提供7×24小时全天候服务,自接到报修电话后应在30分钟以内到达现场抢修,及时恢复正常运行,并实行终身维护。

8.在安装前免费为采购人安排2人去电梯生产厂家处系统地培训

9.中标人供货前须提供控制柜、门机系统、曳引机、曳引钢丝绳等部件品牌、产地、制造商说明,并提供所投电梯全部部件清单及相关技术参数、安装详图、预埋件等书面文件,清单须加盖电梯制造商公章,同时作为正式合同附件。

## 五、施工要求

1. 成立本项目电梯拆除、安装工程项目部,要求

技术人员及安装人员须持有电梯安装作业类《特种设备作业人员证》

除项目评审打分中要求提供的人员证明材料外,以上人员证明材料投标文件中无需提供,项目实施前,由采购人核实,若有虚假,采购人有权终止合同,并报监管部门处理。

2.确保在电梯更换期间办公楼内有两部电梯正常使用,楼内的办公环境不受大的干扰,上班期间不得产生大的噪声,不得影响楼内正常办公。

3.中标人制订出详细的施工方案和施工组织设计,注明施工顺序和每台电梯各阶段的时间安排(包括拆除、安装、检验验收等阶段),争取流水作业,尽量缩短工期。

4. 电梯更换的施工组织设计应包括拆除和安装现场管理、安装组织机构、工期保证措施、工程质量保证措施、安全文明施工技术保证措施等内容,特别注意加强现场的质量管理。

5.中标人要和采购人密切配合,精心施工,加强对采购人电梯厅等部位建筑装潢的保护,避免不必要的损坏,特别不得损伤大楼的承重结构。

6.中标人需大力协助采购人做好机房、井道、层站、底坑等处的土建整改工作

7. 运输电梯材料部件需安排在非上班时段进行,后期注意做好已装新梯轿厢的防护工作。

## 六、旧梯拆除要求

1.本项目原四台电梯的拆除工作由中标人负责实施,拆除费用包含在此次投标报价中,旧电梯由采购人指定地点存放处置。

2.中标人的电梯拆除队伍须具备原省级质量技术监督部门颁发的《中华人民共和国特种设备安装、维修许可证》,须具有B级以上资质。

3. 拆除前需研究制定四台电梯拆除的先后顺序,要和采购人密切配合,必要时联系在用电梯的生产厂家,明确电梯间的控制线路关系和走向,确保在用电梯安全正常使用,电梯群控程序正常运行。

4.在机房拆除控制柜、曳引机时不得对在用电梯造成任何影响,拆下的部件运送到采购人指定地点存放。

5.中标人需统筹安排,尽量缩短旧梯拆除的时间,为新梯的安装多争取一点时间,保证新梯的安装质量。

6.中标人负责旧梯拆除过程中的现场全部安全工作,包括拆除电梯外门和门框

时,负责在各井道门口安放安全护栏或护网等工作。

7.中标人对自己的现场拆除施工人员的人身安全工作负全责

## 七、安全要求

1. 制订周密的措施,确保在电梯机房等处施工时,不对在用电梯的控制柜、曳引机、限速器、配电柜、空调器等设备设施造成任何影响,确保在用电梯安全运行。

2. 电梯安装人员在采购人施工时,需办理出入证,凭证出入。现场安装作业人员需服从采购人的管理,遵守采购人的规章制度,禁止野蛮操作,大声喧哗。

3. 电梯拆除、安装过程中,注意做好现场的安全防护工作,特别是各层门处的安全防护,并且要做好安装人员自身的安全工作,按施工技术规范操作。

4.中标人要和采购人密切配合,做好施工现场的安全防范工作,消除安全隐患

5.中标人在电梯拆除、安装施工中,对施工安全负全责,一旦发生人身、施工安全事故,一切责任由中标人承担。

## 八、交货及验收

1.本项目四台电梯分两次验收,中标人须在新装的两部电梯经检验合格并准许使用后才能进行另外两部旧梯的更换工作。

2. 技术资料:中标人最迟在项目全部竣工验收结束15日内,向采购人移交所有与项目有关的技术资料,如附有安全技术规范要求的设计文件、产品质量合格证明、电梯电气原理图、部件安装图、安装及使用维修说明、监督检验证明、图纸、操作手册等文件。

3.安装调试的方法和措施的书面报告,竣工检查记录表,电梯检验报告书等交工验收资料。

4.安装、调试工作应按GB7588-2003《电梯制造与安装安全规范》、GB50310-2002《电梯工程施工质量验收规范》和GB10060-2011《电梯安装验收规范》进行自检,其中强调指出如下:

(1)测试和调试记录由双方签字并各自保存备查

(2)所有货物在验收前,必须是按出厂标准密封,如自行拆封,采购人有权不予验收;验收时,中标人需提供证明所供货物符合招标文件要求的自检证书,并准备好相关的必需资料,否则不予验收。

(3)安装、调试结束,中标人应通知采购人,双方共同进行预验收,预验收合格后再由省质量技术监督局检验机构进行监督检验,监督检验时中标人应派专人配合。监督检验费用,复检费用由中标人支付。

## 九、报价要求

本项目报总价,投标人报价含原有四部电梯的拆除费(包括部件外运至采购人指定地点),以及四部新梯的供货、运输、安装、调试、井道照明维修、人员培训、政府主管部门的监督检验、验收、技术服务等与投标设备和安装有关的所有费用(含所有关、税费),投标人报价时除报总价外还应同时报出旧梯拆除费、设备费、安装费三项费用。

## 第四章评标方法和标准(综合评分法)

### 一、总则

本项目将按照招标文件第二章投标人须知的相关要求及本章的规定评标

### 二、评标方法

#### 2.1资格审查

依据政府采购相关法律法规规定,由采购人或采购代理机构对投标人进行资格审查。资格审查表如下:

<table border="1" ><tr>
<td colspan="4" rowspan="1">资格审查表</td>
</tr><tr>
<td colspan="1" rowspan="1">序号</td>
<td colspan="1" rowspan="1">评审指标</td>
<td colspan="1" rowspan="1">评审标准</td>
<td colspan="1" rowspan="1">格式及材料要求</td>
</tr><tr>
<td colspan="1" rowspan="1">1 </td>
<td colspan="1" rowspan="1">营业执照</td>
<td colspan="1" rowspan="1">合法有效</td>
<td colspan="1" rowspan="1">提供有效的投标人营业执照(或事业单位法人登记证书)和税务登记证的扫描件,应完整的体现出营业执照(或事业单位法人登记证书)和税务登记证的全</td>
</tr><tr>
<td colspan="1" rowspan="1">2 </td>
<td colspan="1" rowspan="1">税务登记证</td>
<td colspan="1" rowspan="1">合法有效</td>
<td colspan="1" rowspan="1">部内容。已办理“三证合一”登记的,投标文件中提供营业执照(或事业单位法人登记证书)扫描件即可。</td>
</tr><tr>
<td colspan="1" rowspan="1">3 </td>
<td colspan="1" rowspan="1">不良信用记录查询</td>
<td colspan="1" rowspan="1">投标人不得存在投标人须知正文第19.2.1 条中的不良信用记录情形</td>
<td colspan="1" rowspan="1">详见投标人须知正文第19.2条要求</td>
</tr><tr>
<td colspan="1" rowspan="1">4 </td>
<td colspan="1" rowspan="1">无重大违法记录声明函、无不良信用记录声明函</td>
<td colspan="1" rowspan="1">格式、填写要求符合招标文件规定并加盖投标人电子签章</td>
<td colspan="1" rowspan="1">详见第六章投标文件格式三</td>
</tr><tr>
<td colspan="1" rowspan="1">5 </td>
<td colspan="1" rowspan="1">生产厂商资</td>
<td colspan="1" rowspan="1">符合投标人资</td>
<td colspan="1" rowspan="1">提供符合投标人资格中要求的资质证书</td>
</tr></table>
    """
    original_answer= """{\n \"▲乘客电梯-1\": [\n \"控制方式：台集选\",\n \"调速方式：全电脑控制交流变压变频调速\",\n \"额定载重量(kg)：1000\",\n \"额定速度(m/s)：2.0\",\n \"停靠站数(站)：18层18站18门\",\n \"轿厢内尺寸(mm× mm)：无\",\n \"井道尺寸(mmXmm)：2150(宽)*2100(深)\",\n \"顶层高度(mm)：4600\",\n \"底坑深度(mm)：1600\",\n \"提升高度(米)：69\",\n \"曳引机：永磁同步无齿轮\",\n \"净开门尺寸(mm× mm)：900(宽)×2100(高)\",\n \"开门方式：中分式\",\n \"轿厢前壁、两侧壁：304发纹不锈钢,厚度不低于1.0mm 轿厢后壁：镜面不锈钢\",\n \"轿门和轿厢采用发纹不锈钢。首层采用304发纹不锈钢大门套,其它层采用发纹不锈钢小门套。厚度不低于1.0mm,款式:按照更换之前的款式做。\",\n \"轿厢后壁设有不小于15寸的电梯广告机。\",\n \"面板材料采用发纹不锈钢,LCD液晶显示方向及位置指示器。轿厢增设主副操作箱。\",\n \"无障碍功能电梯(具备盲文按钮、语音报站、残疾人操纵箱、后壁整壁镜面不锈钢)。\",\n \"轿厢冷暖空调\",\n \"具备消防运行功能。\",\n \"方向显示灯\",\n \"超速保护功能\",\n \"门采用全光幕保护\",\n \"配置后备电源切换系统,以实现“轿厢应急照明”及“轿厢、机房及控制室在停电时实现五方通话”等功能。\",\n \"轿厢应急照明(LED照明)\",\n \"轿厢、机房及控制室五方对讲通话(机房至监控室的布线由采购人负责)\",\n \"司机操作服务\",\n \"控制柜至轿厢预留防干扰视频电缆及接口,根据采购人要求在适当位置配置电梯专用数字式彩色摄像头\",\n \"泊梯功能\",\n \"安全停靠\",\n \"不能开门时就近层停靠\",\n \"门异常检查装置\",\n \"重复关门\",\n \"超载报警\",\n \"重开梯门\",\n \"开关门时间自动调整\",\n \"反向内指令自动消除功能\",\n \"轿厢照明、风扇自动关闭\",\n \"满载不停\",\n \"故障自检测功能\",\n \"火警紧急返回\",\n \"消防电梯配备紧急消防员服务\",\n \"自动恢复\",\n \"(厅、轿厢)呼梯/登记\",\n \"电动机空载保护功能\",\n \"停车在非门区报警\",\n \"位置异常自动校正\",\n \"无呼自返基站功能\",\n \"运行次数显示功能\",\n \"启动补偿功能\",\n \"层高自测定功能\",\n \"无效内指令自动清除功能\",\n \"轿内误登记信号取消功能\",\n \"并联功能\",\n \"微动平层功能\",\n \"电梯类型：符合招标文件要求\",\n \"控制系统：网络化架构、32位多微机控制系统。要求18层消防梯独立运行。\",\n \"拖动方式：交流变频变压调速系统(VVVF)\",\n \"电源：动力AC380V/50HZ 三相五线制;照明AC220V/50HZ 单相三线。\",\n \"召唤按钮面板：面板材料采用发纹不锈钢,单色液晶显示方向及位置指示器每台电梯使用层每层一套。\",\n \"轿厢壁：304发纹不锈钢,不锈钢板厚均为δ≥1.0mm。\",\n \"轿厢高度及装饰：轿厢装饰后净高度不小于2.5米,采用豪华型天花,LED照明,项目实施前根据不同梯型的使用性质提供三种不同规格商务电梯轿厢装饰方案供采购人选择(费用包含在本次投标报价中)。\",\n \"各个厅门和门套均要求按原实际尺寸订做,层层采用304发纹不锈钢,大门套所用304不锈钢板厚度δ≥1.0mm,款式:按照更换之前的款式设计。\",\n \"厢底材质：中标人提供大理石地板\",\n \"层、轿门地坎：高强度铝合金\",\n \"轿厢操纵箱：发纹不锈钢(整个操纵箱)\",\n \"服务实施前向采购人出具所投电梯的规格参数表和配置功能表原件。\",\n \"服务实施前向采购人出具所投电梯主要材料、零部件、配套件的供货清单(包括名称、位置、单价、用途、规格型号、制造商、产地等)。\",\n \"服务实施前向采购人提供所用群控程序功能的详细列表,如果上述所要求的电梯功能有与所用群控程序相矛盾的,需加以说明。\",\n \"服务实施前向采购人提供电梯保用期后五年内所需的备品备件清单及价格\",\n \"质保期满后,保证设备维修保养所需的备品配件\",\n \"设备到场后,在采购人提供堆放场地上负责保管\",\n \"随机提供的备品备件、专用工具等,供货安装时提供详细清单\",\n \"项目实施前明确质保期满后的正常年维保费用(清包)供采购人参考\",\n \"轿厢地板：地板相对轿厢地坎下凹20mm,采购人提供石材,中标人按照采购人要求的图案安装石材地板;\",\n \"1000KG客梯预留装饰重量150公斤\",\n \"轿厢内应配置语音报站系统\",\n \"通风设施：轴流风扇。\",\n \"制造、安装与验收须符合国标《电梯制造与安装安全规范》(GB7588—2003)、《电梯技术条件》(GB/T10058-2009)、《电梯安装验收规范》(GB10060—2011)中的规定。电梯安装完毕后,必须确保该设备一次性通过特种设备检验部门的监督检验。\",\n \"项目周期(包括制造商生产时间、供货、安装及验收在内)不超过合同签订之日起六个月,两两更换,包括旧梯拆除时间。\",\n \"电梯验收投入使用后运行平稳、乘坐舒适、平层准确,轿厢、机房噪声满足要求,并且长时间候梯率低。\",\n \"本次电梯更换安装工作按照《电梯制造与安装安全规范》(GB7588—2003)、《电梯安装验收规范》(GB10060-2011)和《电梯工程施工质量验收规范》(GB50310-2002) 等电梯相关标准的要求进行。\",\n \"项目实施前中标人须明确所投电梯随机提供的备品备件、专用工具等的详细清单,注明现行价格。\",\n \"中标人项目实施前提供所投产品彩图、技术参数表和相应的机房(包括混凝土开孔图)、井道图纸等技术资料。\",\n \"中标人供货前向采购人提供产品具体的质保期内、外的服务承诺。中标人按《电梯使用管理与维护保养规则》(TSGT5001-2009) 要求,对中标人与设备生产厂家须为中标设备提供质保期2年,自四台电梯全部安装完毕并经质监局监督检验合格之日起算。质保期内进行免费维保。对质保期内出现的所有质量问题,中标人与电梯生产厂家必须及时免费上门包修,提供7×24小时全天候服务,自接到报修电话后应在30分钟以内到达现场抢修,及时恢复正常运行,并实行终身维护。\",\n \"在安装前免费为采购人安排2人去电梯生产厂家处系统地培训\",\n \"中标人供货前须提供控制柜、门机系统、曳引机、曳引钢丝绳等部件品牌、产地、制造商说明,并提供所投电梯全部部件清单及相关技术参数、安装详图、预埋件等书面文件,清单须加盖电梯制造商公章,同时作为正式合同附件。\",\n \"成立本项目电梯拆除、安装工程项目部,要求技术人员及安装人员须持有电梯安装作业类《特种设备作业人员证》\",\n \"确保在电梯更换期间办公楼内有两部电梯正常使用,楼内的办公环境不受大的干扰,上班期间不得产生大的噪声,不得影响楼内正常办公。\",\n \"制订出详细的施工方案和施工组织设计,注明施工顺序和每台电梯各阶段的时间安排(包括拆除、安装、检验验收等阶段),争取流水作业,尽量缩短工期。\",\n \"电梯更换的施工组织设计应包括拆除和安装现场管理、安装组织机构、工期保证措施、工程质量保证措施、安全文明施工技术保证措施等内容,特别注意加强现场的质量管理。\",\n \"中标人要和采购人密切配合,精心施工,加强对采购人电梯厅等部位建筑装潢的保护,避免不必要的损坏,特别不得损伤大楼的承重结构。\",\n \"中标人需大力协助采购人做好机房、井道、层站、底坑等处的土建整改工作\",\n \"运输电梯材料部件需安排在非上班时段进行,后期注意做好已装新梯轿厢的防护工作。\",\n \"本项目原四台电梯的拆除工作由中标人负责实施,拆除费用包含在此次投标报价中,旧电梯由采购人指定地点存放处置。\",\n \"中标人的电梯拆除队伍须具备原省级质量技术监督部门颁发的《中华人民共和国特种设备安装、维修许可证》,须具有B级以上资质。\",\n \"拆除前需研究制定四台电梯拆除的先后顺序,要和采购人密切配合,必要时联系在用电梯的生产厂家,明确电梯间的控制线路关系和走向,确保在用电梯安全正常使用,电梯群控程序正常运行。\",\n \"在机房拆除控制柜、曳引机时不得对在用电梯造成任何影响,拆下的部件运送到采购人指定地点存放。\",\n \"中标人需统筹安排,尽量缩短旧梯拆除的时间,为新梯的安装多争取一点时间,保证新梯的安装质量。\",\n \"中标人负责旧梯拆除过程中的现场全部安全工作,包括拆除电梯外门和门框时,负责在各井道门口安放安全护栏或护网等工作。\",\n \"中标人对自己的现场拆除施工人员的人身安全工作负全责\",\n \"制订周密的措施,确保在电梯机房等处施工时,不对在用电梯的控制柜、曳引机、限速器、配电柜、空调器等设备设施造成任何影响,确保在用电梯安全运行。\",\n \"电梯安装人员在采购人施工时,需办理出入证,凭证出入。现场安装作业人员需服从采购人的管理,遵守采购人的规章制度,禁止野蛮操作,大声喧哗。\",\n \"电梯拆除、安装过程中,注意做好现场的安全防护工作,特别是各层门处的安全防护,并且要做好安装人员自身的安全工作,按施工技术规范操作。\",\n \"中标人要和采购人密切配合,做好施工现场的安全防范工作,消除安全隐患\",\n \"中标人在电梯拆除、安装施工中,对施工安全负全责,一旦发生人身、施工安全事故,一切责任由中标人承担。\",\n \"本项目四台电梯分两次验收,中标人须在新装的两部电梯经检验合格并准许使用后才能进行另外两部旧梯的更换工作。\",\n \"技术资料：中标人最迟在项目全部竣工验收结束15日内,向采购人移交所有与项目有关的技术资料,如附有安全技术规范要求的设计文件、产品质量合格证明、电梯电气原理图、部件安装图、安装及使用维修说明、监督检验证明、图纸、操作手册等文件。\",\n \"安装调试的方法和措施的书面报告,竣工检查记录表,电梯检验报告书等交工验收资料。\",\n \"安装、调试工作应按GB7588-2003《电梯制造与安装安全规范》、GB50310-2002《电梯工程施工质量验收规范》和GB10060-2011《电梯安装验收规范》进行自检\",\n \"测试和调试记录由双方签字并各自保存备查\",\n \"所有货物在验收前,必须是按出厂标准密封,如自行拆封,采购人有权不予验收;验收时,中标人需提供证明所供货物符合招标文件要求的自检证书,并准备好相关的必需资料,否则不予验收。\",\n \"安装、调试结束,中标人应通知采购人,双方共同进行预验收,预验收合格后再由省质量技术监督局检验机构进行监督检验,监督检验时中标人应派专人配合。监督检验费用,复检费用由中标人支付。\",\n \"本项目报总价,投标人报价含原有四部电梯的拆除费(包括部件外运至采购人指定地点),以及四部新梯的供货、运输、安装、调试、井道照明维修、人员培训、政府主管部门的监督检验、验收、技术服务等与投标设备和安装有关的所有费用(含所有关、税费),投标人报价时除报总价外还应同时报出旧梯拆除费、设备费、安装费三项费用。\"\n ],\n \"▲乘客电梯-2\": [\n \"控制方式：三台智能群管理\",\n \"调速方式：全电脑控制交流变压变频调速\",\n \"额定载重量(kg)：1000\",\n \"额定速度(m/s)：2.0\",\n \"停靠站数(站)：2台18层18站18门;1台17层17站17门;\",\n \"轿厢内尺寸(mm× mm)：1600(宽)×1400(深)×2500(高)\",\n \"井道尺寸(mmXmm)：2150(宽)*2300(深)(一台有300*200角柱)\",\n \"顶层高度(mm)：4600\",\n \"底坑深度(mm)：1600\",\n \"提升高度(米)：73\",\n \"曳引机：永磁同步无齿轮\",\n \"净开门尺寸(mm× mm)：900(宽)×2100(高)\",\n \"开门方式：中分式\",\n \"轿厢前壁、两侧壁：304发纹不锈钢,厚度不低于1.0mm 轿厢后壁：镜面不锈钢\",\n \"轿门和轿厢采用发纹不锈钢。首层采用304发纹不锈钢大门套,其它层采用发纹不锈钢小门套。厚度不低于1.0mm,款式:按照更换之前的款式做。\",\n \"轿厢后壁设有不小于15寸的电梯广告机。\",\n \"面板材料采用发纹不锈钢,LCD液晶显示方向及位置指示器。轿厢增设主副操作箱。\",\n \"无障碍功能电梯(具备盲文按钮、语音报站、残疾人操纵箱、后壁整壁镜面不锈钢)。\",\n \"轿厢冷暖空调。其中一台具备消防运行功能。\",\n \"方向显示灯\",\n \"超速保护功能\",\n \"门采用全光幕保护\",\n \"配置后备电源切换系统,以实现“轿厢应急照明”及“轿厢、机房及控制室在停电时实现五方通话”等功能。\",\n \"轿厢应急照明(LED照明)\",\n \"轿厢、机房及控制室五方对讲通话(机房至监控室的布线由采购人负责)\",\n \"司机操作服务\",\n \"控制柜至轿厢预留防干扰视频电缆及接口,根据采购人要求在适当位置配置电梯专用数字式彩色摄像头\",\n \"泊梯功能\",\n \"安全停靠\",\n \"不能开门时就近层停靠\",\n \"门异常检查装置\",\n \"重复关门\",\n \"超载报警\",\n \"重开梯门\",\n \"开关门时间自动调整\",\n \"反向内指令自动消除功能\",\n \"轿厢照明、风扇自动关闭\",\n \"满载不停\",\n \"故障自检测功能\",\n \"火警紧急返回\",\n \"消防电梯配备紧急消防员服务\",\n \"自动恢复\",\n \"(厅、轿厢)呼梯/登记\",\n \"电动机空载保护功能\",\n \"停车在非门区报警\",\n \"位置异常自动校正\",\n \"无呼自返基站功能\",\n \"运行次数显示功能\",\n \"启动补偿功能\",\n \"层高自测定功能\",\n \"无效内指令自动清除功能\",\n \"轿内误登记信号取消功能\",\n \"并联功能\",\n \"微动平层功能\",\n \"电梯类型：符合招标文件要求\",\n \"控制系统：网络化架构、32位多微机控制系统。要求三台智能联控。\",\n \"拖动方式：交流变频变压调速系统(VVVF)\",\n \"电源：动力AC380V/50HZ 三相五线制;照明AC220V/50HZ 单相三线。\",\n \"召唤按钮面板：面板材料采用发纹不锈钢,单色液晶显示方向及位置指示器每台电梯使用层每层一套。\",\n \"轿厢壁：304发纹不锈钢,不锈钢板厚均为δ≥1.0mm。\",\n \"轿厢高度及装饰：轿厢装饰后净高度不小于2.5米,采用豪华型天花,LED照明,项目实施前根据不同梯型的使用性质提供三种不同规格商务电梯轿厢装饰方案供采购人选择(费用包含在本次投标报价中)。\",\n \"各个厅门和门套均要求按原实际尺寸订做,层层采用304发纹不锈钢,大门套所用304不锈钢板厚度δ≥1.0mm,款式:按照更换之前的款式设计。\",\n \"厢底材质：中标人提供大理石地板\",\n \"层、轿门地坎：高强度铝合金\",\n \"轿厢操纵箱：发纹不锈钢(整个操纵箱)\",\n \"服务实施前向采购人出具所投电梯的规格参数表和配置功能表原件。\",\n \"服务实施前向采购人出具所投电梯主要材料、零部件、配套"
"""

    # 调用继续回答功能
    json_result = continue_answer(original_query, original_answer)
    if json_result:
        print(json.dumps(json_result, ensure_ascii=False, indent=4))
